==> open-cluster-management-operator-model-6.0.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KlusterletFluentImpl<A extends KlusterletFluent<A>> extends BaseFluent<A> implements KlusterletFluent<A>{
  public KlusterletFluentImpl() {
  }
  public KlusterletFluentImpl(Klusterlet instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private KlusterletSpecBuilder spec;
  private KlusterletStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public KlusterletFluent.MetadataNested<A> withNewMetadata() {
    return new KlusterletFluentImpl.MetadataNestedImpl();
  }
  public KlusterletFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new KlusterletFluentImpl.MetadataNestedImpl(item);
  }
  public KlusterletFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public KlusterletFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public KlusterletFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public KlusterletSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(KlusterletSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new KlusterletSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public KlusterletFluent.SpecNested<A> withNewSpec() {
    return new KlusterletFluentImpl.SpecNestedImpl();
  }
  public KlusterletFluent.SpecNested<A> withNewSpecLike(KlusterletSpec item) {
    return new KlusterletFluentImpl.SpecNestedImpl(item);
  }
  public KlusterletFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public KlusterletFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new KlusterletSpecBuilder().build());
  }
  public KlusterletFluent.SpecNested<A> editOrNewSpecLike(KlusterletSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public KlusterletStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(KlusterletStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new KlusterletStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public KlusterletFluent.StatusNested<A> withNewStatus() {
    return new KlusterletFluentImpl.StatusNestedImpl();
  }
  public KlusterletFluent.StatusNested<A> withNewStatusLike(KlusterletStatus item) {
    return new KlusterletFluentImpl.StatusNestedImpl(item);
  }
  public KlusterletFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public KlusterletFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new KlusterletStatusBuilder().build());
  }
  public KlusterletFluent.StatusNested<A> editOrNewStatusLike(KlusterletStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KlusterletFluentImpl that = (KlusterletFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<KlusterletFluent.MetadataNested<N>> implements KlusterletFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends KlusterletSpecFluentImpl<KlusterletFluent.SpecNested<N>> implements KlusterletFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(KlusterletSpec item) {
      this.builder = new KlusterletSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new KlusterletSpecBuilder(this);
    }
    KlusterletSpecBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends KlusterletStatusFluentImpl<KlusterletFluent.StatusNested<N>> implements KlusterletFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(KlusterletStatus item) {
      this.builder = new KlusterletStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new KlusterletStatusBuilder(this);
    }
    KlusterletStatusBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KlusterletFluentImpl<A extends KlusterletFluent<A>> extends BaseFluent<A> implements KlusterletFluent<A>{
  public KlusterletFluentImpl() {
  }
  public KlusterletFluentImpl(Klusterlet instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private KlusterletSpecBuilder spec;
  private KlusterletStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public KlusterletFluentImpl.MetadataNested<A> withNewMetadata() {
    return new KlusterletFluentImpl.MetadataNestedImpl();
  }
  public KlusterletFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new KlusterletFluentImpl.MetadataNestedImpl(item);
  }
  public KlusterletFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public KlusterletFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public KlusterletFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public KlusterletSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(KlusterletSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new KlusterletSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public KlusterletFluentImpl.SpecNested<A> withNewSpec() {
    return new KlusterletFluentImpl.SpecNestedImpl();
  }
  public KlusterletFluentImpl.SpecNested<A> withNewSpecLike(KlusterletSpec item) {
    return new KlusterletFluentImpl.SpecNestedImpl(item);
  }
  public KlusterletFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public KlusterletFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new KlusterletSpecBuilder().build());
  }
  public KlusterletFluentImpl.SpecNested<A> editOrNewSpecLike(KlusterletSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public KlusterletStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(KlusterletStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new KlusterletStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public KlusterletFluentImpl.StatusNested<A> withNewStatus() {
    return new KlusterletFluentImpl.StatusNestedImpl();
  }
  public KlusterletFluentImpl.StatusNested<A> withNewStatusLike(KlusterletStatus item) {
    return new KlusterletFluentImpl.StatusNestedImpl(item);
  }
  public KlusterletFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public KlusterletFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new KlusterletStatusBuilder().build());
  }
  public KlusterletFluentImpl.StatusNested<A> editOrNewStatusLike(KlusterletStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KlusterletFluentImpl that = (KlusterletFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<KlusterletFluentImpl.MetadataNested<N>> implements KlusterletFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends KlusterletSpecFluentImpl<KlusterletFluentImpl.SpecNested<N>> implements KlusterletFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(KlusterletSpec item) {
      this.builder = new KlusterletSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new KlusterletSpecBuilder(this);
    }
    KlusterletSpecBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends KlusterletStatusFluentImpl<KlusterletFluentImpl.StatusNested<N>> implements KlusterletFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(KlusterletStatus item) {
      this.builder = new KlusterletStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new KlusterletStatusBuilder(this);
    }
    KlusterletStatusBuilder builder;
    public N and() {
      return (N) KlusterletFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
